@@ -67,4 +67,4 @@ def delete():
         Status(e).failed
 
 if __name__ == '__main__':
-    update()
\ No newline at end of file
+    pass
\ No newline at end of file
